package cn.com.infosec.asn1.esf;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Null;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;

public class SignaturePolicyIdentifier extends ASN1Encodable {
   private SignaturePolicyId signaturePolicyId;
   private boolean isSignaturePolicyImplied;

   public static SignaturePolicyIdentifier getInstance(Object obj) {
      if (obj != null && !(obj instanceof SignaturePolicyIdentifier)) {
         if (obj instanceof ASN1Sequence) {
            return new SignaturePolicyIdentifier(SignaturePolicyId.getInstance(obj));
         } else if (obj instanceof ASN1Null) {
            return new SignaturePolicyIdentifier();
         } else {
            throw new IllegalArgumentException("unknown object in 'SignaturePolicyIdentifier' factory: " + obj.getClass().getName() + ".");
         }
      } else {
         return (SignaturePolicyIdentifier)obj;
      }
   }

   public SignaturePolicyIdentifier() {
      this.isSignaturePolicyImplied = true;
   }

   public SignaturePolicyIdentifier(SignaturePolicyId signaturePolicyId) {
      this.signaturePolicyId = signaturePolicyId;
      this.isSignaturePolicyImplied = false;
   }

   public SignaturePolicyId getSignaturePolicyId() {
      return this.signaturePolicyId;
   }

   public boolean isSignaturePolicyImplied() {
      return this.isSignaturePolicyImplied;
   }

   public DERObject toASN1Object() {
      return (DERObject)(this.isSignaturePolicyImplied ? new DERNull() : this.signaturePolicyId.getDERObject());
   }
}
